@@ -150,7 +150,7 @@ class VisualizationFunctions:
     # MatPlotLib-powered figures
 
     @tryExcept
-    def makeHeatmapGeneExpressionPlot(self, df = None, genes = None, normalize = True, subtract = False, saveExcel = True, nameToAppend = 'heatmap', plotBy = 'cluster', figsize = (8, 4), convertGenes = False, orderGenes=False, orderClusters=False, dpi = 300, extension = 'png', fontsize = 10, **kwargs):
+    def makeHeatmapGeneExpressionPlot(self, df = None, genes = None, normalize = True, subtract = False, saveExcel = True, nameToAppend = 'heatmap', plotBy = 'cluster', figsize = (8, 4), convertGenes = False, orderGenes=False, orderClusters=False, dpi = 300, extension = 'png', fontsize = 10, labelsFontsize = 10, **kwargs):
 
         '''Make heatmap gene expression plot from a provided gene expression matrix.
 
@@ -179,11 +179,8 @@ class VisualizationFunctions:
             DCS.makeHeatmapGeneExpressionPlot()
         '''
 
-        lengthListGenes = []
-        labelsListGenes = []
-
         if not genes is None:
-            if type(genes) in [list, np.array, tuple]:
+            if type(genes) in [list, np.ndarray, tuple]:
                 if convertGenes:
                     genes = np.unique(self.gnc.Convert(genes, 'alias', 'hugo', returnUnknownString=False))
 
@@ -192,22 +189,15 @@ class VisualizationFunctions:
                     for key in genes.keys():
                         genes[key] = self.gnc.Convert(genes[key], 'alias', 'hugo', returnUnknownString=False)
 
-                lengthListGenes = []
-                listGenes = []
-                for key in genes.keys():
-                    listGenes.extend(genes[key])
-                    lengthListGenes.append(len(genes[key]))
-                    labelsListGenes.append(key)
-
-                genes = listGenes
-                print('Length of genes lists:', lengthListGenes)
-
         else:
             if self.verbose >= 1:
                 print('Plotting all expressed genes not supported. Provide a smaller list of genes')
 
             return
 
+        lengthListGenes = []
+        labelsListGenes = []
+
         if df is None:
             if self.df_expr is None:
                 self.loadExpressionData()
@@ -215,11 +205,33 @@ class VisualizationFunctions:
             if self.df_expr is None:
                 return
 
-            common = pd.Index(genes).intersection(self.df_expr.index) #.drop_duplicates()
+            if type(genes) in [list, np.ndarray, tuple]:
+                common = pd.Index(genes).intersection(self.df_expr.index)
+            elif type(genes) in [dict]:
+                common = []
+                for key in genes.keys():
+                    temp_common = pd.Index(genes[key]).intersection(self.df_expr.index)
+                    if len(temp_common) > 0:
+                        common.extend(temp_common)
+                        lengthListGenes.append(len(temp_common))
+                        labelsListGenes.append(key)
+            else:
+                return
+
             df = self.df_expr.loc[common].copy()
 
         else:
-            common = pd.Index(genes).intersection(df.index).drop_duplicates()
+            if type(genes) in [list, np.ndarray, tuple]:
+                common = pd.Index(genes).intersection(df.index)
+            elif type(genes) in [dict]:
+                common = []
+                for key in genes.keys():
+                    temp_common = pd.Index(genes[key]).intersection(self.df_expr.index)
+                    if len(temp_common) > 0:
+                        common.extend(temp_common)
+                        lengthListGenes.append(len(temp_common))
+                        labelsListGenes.append(key)
+
             df = df.loc[common]
 
         counts = df.loc[[df.index[0]]].groupby(axis=1, level=plotBy).count()
